@@ -1,4 +1,5 @@
-﻿define([], function () {
+﻿define(['browser'], function (browser) {
+    'use strict';
 
     var supportsTextTracks;
     var hlsPlayer;
@@ -123,7 +124,7 @@
                 // Appending #t=xxx to the query string doesn't seem to work with HLS
                 if (startPositionInSeekParam && currentSrc.indexOf('.m3u8') != -1) {
 
-                    var delay = browserInfo.safari ? 2500 : 0;
+                    var delay = browser.safari ? 2500 : 0;
                     if (delay) {
                         setTimeout(function () {
                             element.currentTime = startPositionInSeekParam;
@@ -170,7 +171,7 @@
             return elem;
         }
 
-        function enableHlsPlayer(src) {
+        function enableHlsPlayer(src, item, mediaSource) {
 
             if (src) {
                 if (src.indexOf('.m3u8') == -1) {
@@ -178,7 +179,31 @@
                 }
             }
 
-            return MediaPlayer.canPlayHls() && !MediaPlayer.canPlayNativeHls();
+            if (MediaPlayer.canPlayHls()) {
+
+                if (window.MediaSource == null) {
+                    return false;
+                }
+
+                if (MediaPlayer.canPlayNativeHls()) {
+
+                    // simple playback should use the native support
+                    if (mediaSource.RunTimeTicks) {
+                        return false;
+                    }
+
+                    //return false;
+                }
+
+                // hls.js is only in beta. needs more testing.
+                if (browser.safari && !browser.osx) {
+                    return false;
+                }
+
+                return true;
+            }
+
+            return false;
         }
 
         function getCrossOriginValue(mediaSource) {
@@ -193,19 +218,22 @@
             var requiresNativeControls = !self.enableCustomVideoControls();
 
             // Safari often displays the poster under the video and it doesn't look good
-            var poster = !browserInfo.safari && options.poster ? (' poster="' + options.poster + '"') : '';
+            var poster = !browser.safari && options.poster ? (' poster="' + options.poster + '"') : '';
+
+            // playsinline new for iOS 10
+            // https://developer.apple.com/library/content/releasenotes/General/WhatsNewInSafari/Articles/Safari_10_0.html
 
             // Can't autoplay in these browsers so we need to use the full controls
-            if (requiresNativeControls && AppInfo.isNativeApp && browserInfo.android) {
-                html += '<video class="itemVideo" id="itemVideo" preload="metadata" autoplay="autoplay"' + poster + ' webkit-playsinline>';
+            if (requiresNativeControls && AppInfo.isNativeApp && browser.android) {
+                html += '<video class="itemVideo" id="itemVideo" preload="metadata" autoplay="autoplay"' + poster + ' webkit-playsinline playsinline>';
             }
             else if (requiresNativeControls) {
-                html += '<video class="itemVideo" id="itemVideo" preload="metadata" autoplay="autoplay"' + poster + ' controls="controls" webkit-playsinline>';
+                html += '<video class="itemVideo" id="itemVideo" preload="metadata" autoplay="autoplay"' + poster + ' controls="controls" webkit-playsinline playsinline>';
             }
             else {
 
                 // Chrome 35 won't play with preload none
-                html += '<video class="itemVideo" id="itemVideo" preload="metadata" autoplay="autoplay"' + poster + ' webkit-playsinline>';
+                html += '<video class="itemVideo" id="itemVideo" preload="metadata" autoplay="autoplay"' + poster + ' webkit-playsinline playsinline>';
             }
 
             html += '</video>';
@@ -253,7 +281,10 @@
         self.duration = function (val) {
 
             if (mediaElement) {
-                return mediaElement.duration;
+                var duration = mediaElement.duration;
+                if (duration && !isNaN(duration) && duration != Number.POSITIVE_INFINITY && duration != Number.NEGATIVE_INFINITY) {
+                    return duration * 1000;
+                }
             }
 
             return null;
@@ -324,7 +355,7 @@
                 elem.src = "";
 
                 // When the browser regains focus it may start auto-playing the last video
-                if (browserInfo.safari) {
+                if (browser.safari) {
                     elem.src = 'files/dummy.mp4';
                     elem.play();
                 }
@@ -334,7 +365,7 @@
             elem.crossOrigin = getCrossOriginValue(mediaSource);
             var val = streamInfo.url;
 
-            if (AppInfo.isNativeApp && browserInfo.safari) {
+            if (AppInfo.isNativeApp && browser.safari) {
                 val = val.replace('file://', '');
             }
 
@@ -381,17 +412,42 @@
                 }
                 subtitleTrackIndexToSetOnPlaying = currentTrackIndex;
 
-                if (enableHlsPlayer(val)) {
+                if (enableHlsPlayer(val, item, mediaSource)) {
 
                     setTracks(elem, tracks);
 
-                    var hls = new Hls();
-                    hls.loadSource(val);
-                    hls.attachMedia(elem);
-                    hls.on(Hls.Events.MANIFEST_PARSED, function () {
-                        elem.play();
+                    requireHlsPlayer(function () {
+                        var hls = new Hls({
+                            manifestLoadingTimeOut: 20000
+                        });
+                        hls.loadSource(val);
+                        hls.attachMedia(elem);
+                        hls.on(Hls.Events.MANIFEST_PARSED, function () {
+                            elem.play();
+                        });
+
+                        hls.on(Hls.Events.ERROR, function (event, data) {
+                            if (data.fatal) {
+                                switch (data.type) {
+                                    case Hls.ErrorTypes.NETWORK_ERROR:
+                                        // try to recover network error
+                                        console.log("fatal network error encountered, try to recover");
+                                        hls.startLoad();
+                                        break;
+                                    case Hls.ErrorTypes.MEDIA_ERROR:
+                                        console.log("fatal media error encountered, try to recover");
+                                        hls.recoverMediaError();
+                                        break;
+                                    default:
+                                        // cannot recover
+                                        hls.destroy();
+                                        break;
+                                }
+                            }
+                        });
+
+                        hlsPlayer = hls;
                     });
-                    hlsPlayer = hls;
 
                 } else {
 
@@ -503,21 +559,6 @@
 
         function enableNativeTrackSupport(track) {
 
-            if (browserInfo.safari && browserInfo.mobile) {
-                // Leave it to apple to have different behavior between safari on ios vs osx
-                return false;
-            }
-
-            if (browserInfo.edge || browserInfo.msie) {
-                return false;
-            }
-
-            if (browserInfo.firefox) {
-                if ((currentSrc || '').toLowerCase().indexOf('.m3u8') != -1) {
-                    return false;
-                }
-            }
-
             if (track) {
                 var format = (track.format || '').toLowerCase();
                 if (format == 'ssa' || format == 'ass') {
@@ -553,8 +594,6 @@
             }
 
             customTrackIndex = -1;
-            currentSubtitlesElement = null;
-            currentTrackEvents = null;
             currentClock = null;
 
             var renderer = currentAssRenderer;
@@ -564,15 +603,6 @@
             currentAssRenderer = null;
         }
 
-        function fetchSubtitles(track) {
-
-            return ApiClient.ajax({
-                url: track.url.replace('.vtt', '.js'),
-                type: 'GET',
-                dataType: 'json'
-            });
-        }
-
         function setTrackForCustomDisplay(videoElement, track) {
 
             if (!track) {
@@ -588,7 +618,6 @@
             destroyCustomTrack(videoElement, true);
             customTrackIndex = track.index;
             renderTracksEvents(videoElement, track);
-            lastCustomTrackMs = 0;
         }
 
         function renderWithLibjass(videoElement, track) {
@@ -641,55 +670,9 @@
                 renderWithLibjass(videoElement, track);
                 return;
             }
-
-            if (browserInfo.edge || browserInfo.msie) {
-                fetchSubtitles(track).then(function (data) {
-                    currentTrackEvents = data.TrackEvents;
-                });
-                return;
-            }
-
-            var trackElement = null;
-            var expectedId = 'manualTrack' + track.index;
-
-            var allTracks = videoElement.textTracks; // get list of tracks
-            for (var i = 0; i < allTracks.length; i++) {
-
-                var currentTrack = allTracks[i];
-
-                if (currentTrack.label == expectedId) {
-                    trackElement = currentTrack;
-                    break;
-                } else {
-                    currentTrack.mode = 'disabled';
-                }
-            }
-
-            if (!trackElement) {
-                trackElement = videoElement.addTextTrack('subtitles', 'manualTrack' + track.index, track.language || 'und');
-                trackElement.label = 'manualTrack' + track.index;
-
-                // download the track json
-                fetchSubtitles(track).then(function (data) {
-
-                    // show in ui
-                    console.log('downloaded ' + data.TrackEvents.length + ' track events');
-                    // add some cues to show the text
-                    // in safari, the cues need to be added before setting the track mode to showing
-                    data.TrackEvents.forEach(function (trackEvent) {
-                        trackElement.addCue(new (window.VTTCue || window.TextTrackCue)(trackEvent.StartPositionTicks / 10000000, trackEvent.EndPositionTicks / 10000000, trackEvent.Text.replace(/\\N/gi, '\n')));
-                    });
-                    trackElement.mode = 'showing';
-                });
-            } else {
-                trackElement.mode = 'showing';
-            }
         }
 
-        var currentSubtitlesElement;
-        var currentTrackEvents;
         var customTrackIndex = -1;
-        var lastCustomTrackMs = 0;
         var currentClock;
         var currentAssRenderer;
         function updateSubtitleText(timeMs) {
@@ -698,44 +681,6 @@
             if (clock) {
                 clock.seek(timeMs / 1000);
             }
-
-            var trackEvents = currentTrackEvents;
-            if (!trackEvents) {
-                return;
-            }
-
-            if (!currentSubtitlesElement) {
-                var videoSubtitlesElem = document.querySelector('.videoSubtitles');
-                if (!videoSubtitlesElem) {
-                    videoSubtitlesElem = document.createElement('div');
-                    videoSubtitlesElem.classList.add('videoSubtitles');
-                    videoSubtitlesElem.innerHTML = '<div class="videoSubtitlesInner"></div>';
-                    document.body.appendChild(videoSubtitlesElem);
-                }
-                currentSubtitlesElement = videoSubtitlesElem.querySelector('.videoSubtitlesInner');
-            }
-
-            if (lastCustomTrackMs > 0) {
-                if (Math.abs(lastCustomTrackMs - timeMs) < 500) {
-                    return;
-                }
-            }
-
-            lastCustomTrackMs = new Date().getTime();
-
-            var positionTicks = timeMs * 10000;
-            for (var i = 0, length = trackEvents.length; i < length; i++) {
-
-                var caption = trackEvents[i];
-                if (positionTicks >= caption.StartPositionTicks && positionTicks <= caption.EndPositionTicks) {
-                    currentSubtitlesElement.innerHTML = caption.Text;
-                    currentSubtitlesElement.classList.remove('hide');
-                    return;
-                }
-            }
-
-            currentSubtitlesElement.innerHTML = '';
-            currentSubtitlesElement.classList.add('hide');
         }
 
         self.setCurrentTrackElement = function (streamIndex) {
@@ -767,13 +712,14 @@
                 var currentTrack = allTracks[i];
 
                 console.log('currentTrack id: ' + currentTrack.id);
+                console.log('currentTrack label: ' + currentTrack.label);
 
                 var mode;
 
                 console.log('expectedId: ' + expectedId + '--currentTrack.Id:' + currentTrack.id);
 
                 // IE doesn't support track id
-                if (browserInfo.msie || browserInfo.edge) {
+                if (browser.msie || browser.edge) {
                     if (trackIndex == i) {
                         mode = 1; // show this track
                     } else {
@@ -860,9 +806,9 @@
 
         self.enableCustomVideoControls = function () {
 
-            if (AppInfo.isNativeApp && browserInfo.safari) {
+            if (AppInfo.isNativeApp && browser.safari) {
 
-                if (navigator.userAgent.toLowerCase().indexOf('ipad') != -1) {
+                if (browser.ipad) {
                     // Need to disable it in order to support picture in picture
                     return false;
                 }
@@ -879,7 +825,7 @@
                 return true;
             }
 
-            if (browserInfo.mobile) {
+            if (browser.mobile) {
                 return false;
             }
 
@@ -888,16 +834,7 @@
 
         self.init = function () {
 
-            return new Promise(function (resolve, reject) {
-
-                if (options.type == 'video' && enableHlsPlayer()) {
-
-                    requireHlsPlayer(resolve);
-
-                } else {
-                    resolve();
-                }
-            });
+            return Promise.resolve();
         };
 
         if (options.type == 'audio') {
