@@ -1,4 +1,5 @@
-﻿define(['appSettings', 'datetime', 'mediaInfo', 'browser', 'scrollStyles', 'paper-icon-button-light'], function (appSettings, datetime, mediaInfo, browser) {
+﻿define(['appSettings', 'datetime', 'mediaInfo', 'browser', 'imageLoader', 'scrollStyles', 'paper-icon-button-light'], function (appSettings, datetime, mediaInfo, browser, imageLoader) {
+    'use strict';
 
     function createVideoPlayer(self) {
 
@@ -425,11 +426,11 @@
                         width: 160,
                         shape: 'portrait'
                     });
-                    ImageLoader.lazyChildren(elem);
+                    imageLoader.lazyChildren(elem);
                 });
             }
             else {
-                ImageLoader.lazyChildren(elem);
+                imageLoader.lazyChildren(elem);
             }
 
             function onTabButtonClick() {
@@ -981,18 +982,27 @@
                         var hlsPlaylistUrl = streamInfo.url.replace('master.m3u8', 'live.m3u8');
 
                         Dashboard.showLoadingMsg();
+
+                        console.log('prefetching hls playlist: ' + hlsPlaylistUrl);
+
                         ApiClient.ajax({
 
                             type: 'GET',
                             url: hlsPlaylistUrl
 
                         }).then(function () {
+
+                            console.log('completed prefetching hls playlist: ' + hlsPlaylistUrl);
+
                             Dashboard.hideLoadingMsg();
                             streamInfo.url = hlsPlaylistUrl;
 
                             setTimeout(onReadyToPlay, 0);
 
                         }, function () {
+
+                            console.log('error prefetching hls playlist: ' + hlsPlaylistUrl);
+
                             Dashboard.hideLoadingMsg();
                         });
 
